@@ -8,7 +8,6 @@ from twisted.internet.task import LoopingCall
 from twisted.python import log
 from zope.interface import implements
 
-from bravo.config import configuration
 from bravo.entity import entities
 from bravo.ibravo import (ISortedPlugin, IAutomaton, IAuthenticator, ISeason,
     ITerrainGenerator, IUseHook, ISignHook, IPreDigHook, IDigHook, IPreBuildHook,
@@ -18,7 +17,6 @@ from bravo.beta.packets import make_packet
 from bravo.plugin import retrieve_named_plugins, retrieve_sorted_plugins
 from bravo.beta.protocol import BravoProtocol, KickedProtocol
 from bravo.utilities.chat import chat_name, sanitize_chat
-from bravo.utilities.furnace import FurnaceManager
 from bravo.weather import WeatherVane
 from bravo.world import World
 
@@ -49,7 +47,7 @@ class BravoFactory(Factory):
 
     interfaces = []
 
-    def __init__(self, name):
+    def __init__(self, config, name):
         """
         Create a factory and world.
 
@@ -60,31 +58,31 @@ class BravoFactory(Factory):
         """
 
         self.name = name
+        self.config = config
         self.config_name = "world %s" % name
 
-        self.world = World(self.name)
+        self.world = World(self.config, self.name)
         self.world.factory = self
 
         self.protocols = dict()
         self.connectedIPs = defaultdict(int)
 
-        self.mode = configuration.get(self.config_name, "mode")
+        self.mode = self.config.get(self.config_name, "mode")
         if self.mode not in ("creative", "survival"):
             raise Exception("Unsupported mode %s" % self.mode)
 
-        self.limitConnections = configuration.getintdefault(self.config_name,
+        self.limitConnections = self.config.getintdefault(self.config_name,
                                                             "limitConnections",
                                                             0)
-        self.limitPerIP = configuration.getintdefault(self.config_name,
+        self.limitPerIP = self.config.getintdefault(self.config_name,
                                                       "limitPerIP", 0)
 
-        self.furnace_manager = FurnaceManager(self)
         self.vane = WeatherVane(self)
 
     def startFactory(self):
         log.msg("Initializing factory for world '%s'..." % self.name)
 
-        authenticator = configuration.get(self.config_name, "authenticator")
+        authenticator = self.config.get(self.config_name, "authenticator")
         selected = retrieve_named_plugins(IAuthenticator, [authenticator])[0]
 
         log.msg("Using authenticator %s" % selected.name)
@@ -97,8 +95,11 @@ class BravoFactory(Factory):
         log.msg("Starting world...")
         self.world.start()
 
-        if configuration.has_option(self.config_name, "perm_cache"):
-            cache_level = configuration.getint(self.config_name, "perm_cache")
+        # Start up the permanent cache.
+        # has_option() is not exactly desirable, but it's appropriate here
+        # because we don't want to take any action if the key is unset.
+        if self.config.has_option(self.config_name, "perm_cache"):
+            cache_level = self.config.getint(self.config_name, "perm_cache")
             self.world.enable_cache(cache_level)
 
         log.msg("Starting timekeeping...")
@@ -110,9 +111,6 @@ class BravoFactory(Factory):
 
         log.msg("Starting entity updates...")
 
-        log.msg("Starting furnaces...")
-        self.furnace_manager.start()
-
         # Start automatons.
         for automaton in self.automatons:
             automaton.start()
@@ -141,7 +139,6 @@ class BravoFactory(Factory):
         self.unregister_plugins()
 
         self.time_loop.stop()
-        self.furnace_manager.stop()
 
         # Write back current world time. This must be done before stopping the
         # world.
@@ -181,11 +178,9 @@ class BravoFactory(Factory):
             p.factory = self
             return p
 
-        # This probably a needs cleanup. We need to see if that IP has
-        # connected already, check if +1 connections is ok, and ignore
-        # values less than 1.
-        if (self.limitPerIP and addr.host in self.connectedIPs.keys()
-            and self.connectedIPs[addr.host] >= self.limitPerIP):
+        # Do our connection-per-IP check.
+        if (self.limitPerIP and
+            self.connectedIPs[addr.host] >= self.limitPerIP):
             log.msg("At maximum connections for %s already, dropping." % addr.host)
             p = KickedProtocol("There are too many players connected from this IP.")
             p.factory = self
@@ -195,7 +190,7 @@ class BravoFactory(Factory):
 
         # If the player wasn't kicked, let's continue!
         log.msg("Starting connection for %s" % addr)
-        p = self.protocol(self.name)
+        p = self.protocol(self.config, self.name)
         p.host = addr.host
         p.factory = self
 
@@ -206,6 +201,23 @@ class BravoFactory(Factory):
 
         return p
 
+    def teardown_protocol(self, protocol):
+        """
+        Do internal bookkeeping on behalf of a protocol which has been
+        disconnected.
+
+        Did you know that "bookkeeping" is one of the few words in English
+        which has three pairs of double letters in a row?
+        """
+
+        username = protocol.username
+        host = protocol.host
+
+        if username in self.protocols:
+            del self.protocols[username]
+
+        self.connectedIPs[host] -= 1
+
     def set_username(self, protocol, username):
         """
         Attempt to set a new username for a protocol.
@@ -249,11 +261,10 @@ class BravoFactory(Factory):
             "use_hooks": IUseHook,
         }
 
-        pp = {"factory": self,
-              "furnaces": self.furnace_manager}
+        pp = {"factory": self}
 
         for t, interface in plugin_types.iteritems():
-            l = configuration.getlistdefault(self.config_name, t, [])
+            l = self.config.getlistdefault(self.config_name, t, [])
             if issubclass(interface, ISortedPlugin):
                 plugins = retrieve_sorted_plugins(interface, l, parameters=pp)
             else:
