@@ -334,23 +334,23 @@ packets = {
     ),
     24: Struct("mob",
         UBInt32("eid"),
-        Enum(UBInt8("type"),
-            creeper=50,
-            skeleton=51,
-            spider=52,
-            giant_zombie=53,
-            zombie=54,
-            slime=55,
-            ghast=56,
-            pigman=57,
-            enderman=58,
-            pig=90,
-            sheep=91,
-            cow=92,
-            chuck=93,
-            squid=94,
-            wolf=95,
-        ),
+        Enum(UBInt8("type"), **{
+            "Creeper": 50,
+            "Skeleton": 51,
+            "Spider": 52,
+            "GiantZombie": 53,
+            "Zombie": 54,
+            "Slime": 55,
+            "Ghast": 56,
+            "ZombiePig": 57,
+            "Enderman": 58,
+            "Pig": 90,
+            "Sheep": 91,
+            "Cow": 92,
+            "Chicken": 93,
+            "Squid": 94,
+            "Wolf": 95,
+        }),
         SBInt32("x"),
         SBInt32("y"),
         SBInt32("z"),
