@@ -17,7 +17,6 @@ from twisted.web.client import getPage
 
 from bravo.beta.structures import BuildData
 from bravo.blocks import blocks, items
-from bravo.config import configuration
 from bravo.entity import Sign
 from bravo.errors import BetaClientError, BuildError
 from bravo.ibravo import (IChatCommand, IPreBuildHook, IPostBuildHook,
@@ -32,6 +31,7 @@ from bravo.plugin import retrieve_plugins
 from bravo.policy.dig import dig_policies
 from bravo.utilities.coords import adjust_coords_for_face, split_coords
 from bravo.utilities.chat import username_alternatives
+from bravo.utilities.maths import clamp
 from bravo.utilities.temporal import timestamp_from_clock
 
 (STATE_UNAUTHENTICATED, STATE_CHALLENGED, STATE_AUTHENTICATED) = range(3)
@@ -458,6 +458,11 @@ class BetaServerProtocol(object, Protocol, TimeoutMixin):
 
     @latency.setter
     def latency(self, value):
+        # Clamp the value to not exceed the boundaries of the packet. This is
+        # necessary even though, in theory, a ping this high is bad news.
+        value = clamp(value, 0, 65535)
+
+        # Check to see if this is a new value, and if so, alert everybody.
         if self._latency != value:
             packet = make_packet("players", name=self.username, online=True,
                 ping=value)
@@ -552,19 +557,18 @@ class BravoProtocol(BetaServerProtocol):
 
     last_dig = None
 
-    def __init__(self, name):
+    def __init__(self, config, name):
         BetaServerProtocol.__init__(self)
 
+        self.config = config
         self.config_name = "world %s" % name
 
-        log.msg("Registering client hooks...")
-
         # Retrieve the MOTD. Only needs to be done once.
-        self.motd = configuration.getdefault(self.config_name, "motd",
+        self.motd = self.config.getdefault(self.config_name, "motd",
             "BravoServer")
 
     def register_hooks(self):
-
+        log.msg("Registering client hooks...")
         plugin_types = {
             "open_hooks": IWindowOpenHook,
             "click_hooks": IWindowClickHook,
@@ -581,7 +585,10 @@ class BravoProtocol(BetaServerProtocol):
             setattr(self, t, getattr(self.factory, t))
 
         log.msg("Registering policies...")
-        self.dig_policy = dig_policies["notchy"]
+        if self.factory.mode == "creative":
+            self.dig_policy = dig_policies["speedy"]
+        else:
+            self.dig_policy = dig_policies["notchy"]
 
         log.msg("Registered client plugin hooks!")
 
@@ -1242,6 +1249,37 @@ class BravoProtocol(BetaServerProtocol):
         self.write_packet("time", timestamp=int(self.factory.time))
 
     def connectionLost(self, reason):
+        """
+        Cleanup after a lost connection.
+
+        Most of the time, these connections are lost cleanly; we don't have
+        any cleanup to do in the unclean case since clients don't have any
+        kind of pending state which must be recovered.
+
+        Remember, the connection can be lost before identification and
+        authentication, so ``self.username`` and ``self.player`` can be None.
+        """
+
+        if self.username and self.player:
+            self.factory.world.save_player(self.username, self.player)
+
+        if self.player:
+            self.factory.destroy_entity(self.player)
+            packet = make_packet("destroy", eid=self.player.eid)
+            self.factory.broadcast(packet)
+
+        if self.username:
+            packet = make_packet("players", name=self.username, online=False,
+                ping=0)
+            self.factory.broadcast(packet)
+            self.factory.chat("%s has left the game." % self.username)
+
+        self.factory.teardown_protocol(self)
+
+        # We are now torn down. After this point, there will be no more
+        # factory stuff, just our own personal stuff.
+        del self.factory
+
         if self.time_loop:
             self.time_loop.stop()
 
@@ -1251,20 +1289,3 @@ class BravoProtocol(BetaServerProtocol):
                     task.stop()
                 except (TaskDone, TaskFailed):
                     pass
-
-        if self.player:
-            self.factory.world.save_player(self.username, self.player)
-            self.factory.destroy_entity(self.player)
-            packet = make_packet("destroy", eid=self.player.eid)
-            packet += make_packet("players", name=self.username, online=False,
-                ping=0)
-            self.factory.broadcast(packet)
-            self.factory.chat("%s has left the game." % self.username)
-
-        if self.username in self.factory.protocols:
-            del self.factory.protocols[self.username]
-
-        self.factory.connectedIPs[self.host] -= 1
-
-        if self.factory.connectedIPs[self.host] <= 0:
-            del self.factory.connectedIPs[self.host]
