@@ -95,7 +95,7 @@ class Block(object):
         if self.replace:
             attributes.append("becomes %d" % self.replace)
         if self.ratio != 1 or self.quantity > 1 or self.drop != self.key:
-            attributes.append("drops %r slot %d rate %2.2f%%" %
+            attributes.append("drops %r (key %r, rate %2.2f%%)" %
                 (self.quantity, self.drop, self.ratio * 100))
         if attributes:
             attributes = ": %s" % ", ".join(attributes)
@@ -198,11 +198,11 @@ block_names = [
     "bed-block",
     "powered-rail",
     "detector-rail",
-    "",
+    "sticky-piston",
     "spider-web",
     "tall-grass",
     "shrub", # 0x20
-    "",
+    "piston",
     "",
     "wool",
     "",
@@ -265,11 +265,30 @@ block_names = [
     "redstone-repeater-off",
     "redstone-repeater-on",
     "locked-chest",
-    "trapdoor", #0x60
+    "trapdoor", # 0x60
+    "hidden-silverfish",
+    "stone-brick",
+    "huge-brown-mushroom",
+    "huge-red-mushroom",
+    "iron-bars",
+    "glass-pane",
+    "melon",
+    "pumpkin-stem",
+    "melon-stem",
+    "vine",
+    "fence-gate",
+    "brick-stairs",
+    "stone-brick-stairs",
+    "mycelium",
+    "lily-pad",
+    "nether-brick", # 0x70
+    "nether-brick-fence",
+    "nether-brick-stairs",
+    "nether-wart-block", # 0x73
 ]
 
 item_names = [
-    "iron-shovel",
+    "iron-shovel", # 0x100
     "iron-pickaxe",
     "iron-axe",
     "flint-and-steel",
@@ -285,7 +304,7 @@ item_names = [
     "wooden-shovel",
     "wooden-pickaxe",
     "wooden-axe",
-    "stone-sword",
+    "stone-sword", # 0x110
     "stone-shovel",
     "stone-pickaxe",
     "stone-axe",
@@ -301,7 +320,7 @@ item_names = [
     "gold-pickaxe",
     "gold-axe",
     "string",
-    "feather",
+    "feather", # 0x120
     "sulphur",
     "wooden-hoe",
     "stone-hoe",
@@ -317,7 +336,7 @@ item_names = [
     "leather-boots",
     "chainmail-helmet",
     "chainmail-chestplate",
-    "chainmail-leggings",
+    "chainmail-leggings", # 0x130
     "chainmail-boots",
     "iron-helmet",
     "iron-chestplate",
@@ -333,7 +352,7 @@ item_names = [
     "gold-boots",
     "flint",
     "raw-porkchop",
-    "cooked-porkchop",
+    "cooked-porkchop", # 0x140
     "paintings",
     "golden-apple",
     "sign",
@@ -349,7 +368,7 @@ item_names = [
     "boat",
     "leather",
     "milk",
-    "clay-brick",
+    "clay-brick", # 0x150
     "clay-balls",
     "sugar-cane",
     "paper",
@@ -365,17 +384,41 @@ item_names = [
     "raw-fish",
     "cooked-fish",
     "dye",
-    "bone",
+    "bone", # 0x160
     "sugar",
     "cake",
     "bed",
     "redstone-repeater",
     "cookie",
+    "map",
+    "shears",
+    "melon-slice",
+    "pumpkin-seeds",
+    "melon-seeds",
+    "raw-beef",
+    "steak",
+    "raw-chicken",
+    "cooked-chicken",
+    "rotten-flesh",
+    "ender-pearl", # 0x170
+    "blaze-rod",
+    "ghast-tear",
+    "gold-nugget",
+    "nether-wart",
+    "potions",
+    "glass-bottle",
+    "spider-eye",
+    "fermented-spider-eye",
+    "blaze-powder",
+    "magma-cream", # 0x17a
 ]
 
 special_item_names = [
     "gold-music-disc",
     "green-music-disc",
+    "blocks-music-disc",
+    "chirp-music-disc",
+    "far-music-disc"
 ]
 
 dye_names = [
@@ -459,14 +502,19 @@ drops[62] = (61, 0) # Burning Furnace -> Furnace
 drops[78] = (0, 0)  # Snow
 
 # Block -> item drops.
-drops[16] = (263, 0) # Coal Ore Block         -> Coal
-drops[56] = (264, 0) # Diamond Ore Block      -> Diamond
-drops[63] = (323, 0) # Sign Post              -> Sign Item
-drops[68] = (323, 0) # Wall Sign              -> Sign Item
-drops[83] = (338, 0) # Reed                   -> Reed Item
-drops[89] = (348, 0) # Lightstone             -> Lightstone Dust
-drops[93] = (356, 0) # Redstone Repeater, on  -> Redstone Repeater
-drops[94] = (356, 0) # Redstone Repeater, off -> Redstone Repeater
+drops[16] = (263, 0)  # Coal Ore Block         -> Coal
+drops[56] = (264, 0)  # Diamond Ore Block      -> Diamond
+drops[63] = (323, 0)  # Sign Post              -> Sign Item
+drops[68] = (323, 0)  # Wall Sign              -> Sign Item
+drops[83] = (338, 0)  # Reed                   -> Reed Item
+drops[89] = (348, 0)  # Lightstone             -> Lightstone Dust
+drops[93] = (356, 0)  # Redstone Repeater, on  -> Redstone Repeater
+drops[94] = (356, 0)  # Redstone Repeater, off -> Redstone Repeater
+drops[97] = (0, 0)    # Hidden Silverfish
+drops[110] = (3, 0)   # Mycelium               -> Dirt
+drops[111] = (0, 0)   # Lily Pad
+drops[115] = (372, 0) # Nether Wart BLock      -> Nether Wart
+
 
 
 unbreakables = set()
@@ -551,8 +599,11 @@ _add_block(Block(64, "wooden-door-block", drop=(324, 0),
     orientation=(None, None, 1, 3, 0, 2)))
 # Ladders are orientable and don't dim.
 _add_block(Block(65, "ladder", orientation=(None, None, 2, 3, 4, 5), dim=0))
-# Levers are orientable and don't dim.
+# Levers are orientable and don't dim. Additionally, levers have special hax
+# to be orientable two different ways.
 _add_block(Block(69, "lever", orientation=(None, 5, 4, 3, 2, 1), dim=0))
+blocks["lever"]._f_dict.update(
+    {13: "+y", 12: "-z", 11: "+z", 10: "-x", 9: "+x"})
 # Iron Door is orientable and drops Iron Door item
 _add_block(Block(71, "iron-door-block", drop=(330, 0),
     orientation=(None, None, 1, 3, 0, 2)))
@@ -570,6 +621,14 @@ _add_block(Block(79, "ice", drop=(0, 0), replace=9, dim=3))
 _add_block(Block(82, "clay", drop=(337, 0), quantity=4))
 # Trapdoor is orientable
 _add_block(Block(96, "trapdoor", orientation=(None, None, 0, 1, 2, 3)))
+# Giant brown mushrooms drop brown mushrooms.
+_add_block(Block(99, "huge-brown-mushroom", drop=(39, 0), quantity=2))
+# Giant red mushrooms drop red mushrooms.
+_add_block(Block(100, "huge-red-mushroom", drop=(40, 0), quantity=2))
+# Pumpkin stems drop pumpkin seeds.
+_add_block(Block(104, "pumpkin-stem", drop=(361, 0), quantity=3))
+# Melon stems drop melon seeds.
+_add_block(Block(105, "melon-stem", drop=(362, 0), quantity=3))
 
 for block in blocks.values():
     blocks[block.name] = block
