@@ -1,3 +1,4 @@
+from functools import wraps
 from itertools import product
 from warnings import warn
 
@@ -7,6 +8,7 @@ from numpy import vectorize
 from bravo.blocks import blocks, glowing_blocks
 from bravo.beta.packets import make_packet
 from bravo.utilities.bits import pack_nibbles
+from bravo.utilities.maths import clamp
 
 class ChunkWarning(Warning):
     """
@@ -14,6 +16,32 @@ class ChunkWarning(Warning):
     lethal, so the chunk is issuing a warning instead of an exception.
     """
 
+def check_bounds(f):
+    """
+    Decorate a function or method to have its first positional argument be
+    treated as an (x, y, z) tuple which must fit inside chunk boundaries of
+    16, 128, and 16, respectively.
+
+    A warning will be raised if the bounds check fails.
+    """
+
+    @wraps(f)
+    def deco(chunk, coords, *args, **kwargs):
+        x, y, z = coords
+
+        # Coordinates were out-of-bounds; warn and run away.
+        if not (0 <= x < 16 or 0 <= z < 16 or 0 <= y < 128):
+            warn("Coordinates %s are OOB in %s() of %s, ignoring call"
+                % (coords, f.func_name, chunk), ChunkWarning)
+            # A concession towards where this decorator will be used. The
+            # value is likely to be discarded either way, but if the value is
+            # used, we shouldn't horribly die because of None/0 mismatch.
+            return 0
+
+        return f(chunk, coords, *args, **kwargs)
+
+    return deco
+
 # Set up glow tables.
 # These tables provide glow maps for illuminated points.
 glow = [None] * 16
@@ -68,6 +96,49 @@ def composite_glow(target, strength, x, y, z):
     # Composite!
     target[sx:ex, sz:ez, sy:ey] += ambient[si:ei, sk:ek, sj:ej]
 
+def iter_neighbors(coords):
+    """
+    Iterate over the chunk-local coordinates surrounding the given
+    coordinates.
+
+    All coordinates are chunk-local.
+
+    Coordinates which are not valid chunk-local coordinates will not be
+    generated.
+    """
+
+    x, z, y = coords
+
+    for dx, dz, dy in (
+        (1, 0, 0),
+        (-1, 0, 0),
+        (0, 1, 0),
+        (0, -1, 0),
+        (0, 0, 1),
+        (0, 0, -1)):
+        nx = x + dx
+        nz = z + dz
+        ny = y + dy
+
+        if not (0 <= nx < 16 and
+            0 <= nz < 16 and
+            0 <= ny < 128):
+            continue
+
+        yield nx, nz, ny
+
+def neighboring_light(glow, block):
+    """
+    Calculate the amount of light that should be shone on a block.
+
+    ``glow`` is the brighest neighboring light. ``block`` is the slot of the
+    block being illuminated.
+
+    The return value is always a valid light value.
+    """
+
+    return clamp(glow - blocks[block].dim, 0, 15)
+
 class Chunk(object):
     """
     A chunk of blocks.
@@ -146,9 +217,6 @@ class Chunk(object):
 
         self.blocklight = cast["uint8"](lightmap.clip(0, 15))
 
-    def regenerate_metadata(self):
-        pass
-
     def regenerate_skylight(self):
         """
         Regenerate the ambient light map.
@@ -211,48 +279,36 @@ class Chunk(object):
 
         # Run the actual glow loop. For each glow level, go over unvisited air
         # blocks and illuminate them.
-        for glow in range(14, 0, -1):
+        for glow in xrange(14, 0, -1):
             for coords in spread:
                 if lightmap[coords] <= glow:
                     visited.add(coords)
                     continue
 
-                for dx, dz, dy in (
-                    (1, 0, 0),
-                    (-1, 0, 0),
-                    (0, 1, 0),
-                    (0, -1, 0),
-                    (0, 0, 1),
-                    (0, 0, -1)):
-                    x, z, y = coords
-                    x += dx
-                    z += dz
-                    y += dy
-
-                    if not (0 <= x < 16 and
-                        0 <= z < 16 and
-                        0 <= y < 128):
+                for target in iter_neighbors(coords):
+                    # Skip targets that already have valid lighting.
+                    if target in visited:
                         continue
 
-                    if (x, z, y) in visited:
-                        continue
-
-                    if lightable[x, z, y] and lightmap[x, z, y] < glow:
-                        lightmap[x, z, y] = glow - blocks[self.blocks[x, z, y]].dim
-                        visited.add((x, z, y))
+                    # If the block's lightable and the lightmap isn't fully
+                    # lit up, then light the block appropriately and mark it
+                    # as visited.
+                    if lightable[target] and lightmap[target] < glow:
+                        light = neighboring_light(glow, self.blocks[target])
+                        lightmap[target] = light
+                        visited.add(target)
             spread = visited
             visited = set()
 
-        self.skylight = lightmap.clip(0, 15)
+        self.skylight = lightmap
 
     def regenerate(self):
         """
-        Regenerate all extraneous tables.
+        Regenerate all auxiliary tables.
         """
 
         self.regenerate_heightmap()
         self.regenerate_blocklight()
-        self.regenerate_metadata()
         self.regenerate_skylight()
 
         self.dirty = True
@@ -358,6 +414,7 @@ class Chunk(object):
             x_size=15, y_size=127, z_size=15, data=array)
         return packet
 
+    @check_bounds
     def get_block(self, coords):
         """
         Look up a block value.
@@ -367,15 +424,10 @@ class Chunk(object):
         :returns: int representing block type
         """
 
-        try:
-            x, y, z = coords
-            return self.blocks[x, z, y]
-        except IndexError:
-            # Coordinates were out-of-bounds; warn and pretend it's air.
-            warn("Coordinates %s are out-of-bounds in %s" % (coords, self),
-                 ChunkWarning)
-            return 0
+        x, y, z = coords
+        return self.blocks[x, z, y]
 
+    @check_bounds
     def set_block(self, coords, block):
         """
         Update a block value.
@@ -386,40 +438,41 @@ class Chunk(object):
 
         x, y, z = coords
 
-        try:
-            if self.blocks[x, z, y] != block:
-                self.blocks[x, z, y] = block
+        if self.blocks[x, z, y] != block:
+            self.blocks[x, z, y] = block
 
-                if not self.populated:
-                    return
+            if not self.populated:
+                return
 
-                # Regenerate heightmap at this coordinate.
-                if not block:
-                    # If we replace the highest block with air, we need to go
-                    # through all blocks below it to find the new top block.
-                    height = self.heightmap[x, z]
-                    if y == height:
-                        for y in range(height, -1, -1):
-                            if self.blocks[x, z, y]:
-                                break
-                        self.heightmap[x, z] = y
-                else:
-                    self.heightmap[x, z] = max(self.heightmap[x, z], y)
+            # Regenerate heightmap at this coordinate.
+            if block:
+                self.heightmap[x, z] = max(self.heightmap[x, z], y)
+            else:
+                # If we replace the highest block with air, we need to go
+                # through all blocks below it to find the new top block.
+                height = self.heightmap[x, z]
+                if y == height:
+                    for y in range(height, -1, -1):
+                        if self.blocks[x, z, y]:
+                            break
+                    self.heightmap[x, z] = y
 
-                # Add to lightmap at this coordinate.
-                if block in glowing_blocks:
-                    composite_glow(self.blocklight, glowing_blocks[block],
-                        x, y, z)
+            # Do the blocklight at this coordinate, if appropriate.
+            if block in glowing_blocks:
+                composite_glow(self.blocklight, glowing_blocks[block],
+                    x, y, z)
 
-                    self.blocklight = cast["uint8"](self.blocklight.clip(0, 15))
+                self.blocklight = cast["uint8"](self.blocklight.clip(0, 15))
 
-                self.dirty = True
-                self.damage(coords)
-        except IndexError:
-            # Coordinates were out-of-bounds; warn and run away.
-            warn("Coordinates %s are out-of-bounds in %s" % (coords, self),
-                 ChunkWarning)
+            # And the skylight.
+            glow = max(self.skylight[neighbor]
+                for neighbor in iter_neighbors((x, z, y)))
+            self.skylight[x, z, y] = neighboring_light(glow, block)
 
+            self.dirty = True
+            self.damage(coords)
+
+    @check_bounds
     def get_metadata(self, coords):
         """
         Look up metadata.
@@ -429,15 +482,9 @@ class Chunk(object):
         """
 
         x, y, z = coords
+        return self.metadata[x, z, y]
 
-        try:
-            return self.metadata[x, z, y]
-        except IndexError:
-            # Coordinates were out-of-bounds; warn.
-            warn("Coordinates %s are out-of-bounds in %s" % (coords, self),
-                 ChunkWarning)
-            return 0
-
+    @check_bounds
     def set_metadata(self, coords, metadata):
         """
         Update metadata.
@@ -448,17 +495,13 @@ class Chunk(object):
 
         x, y, z = coords
 
-        try:
-            if self.metadata[x, z, y] != metadata:
-                self.metadata[x, z, y] = metadata
+        if self.metadata[x, z, y] != metadata:
+            self.metadata[x, z, y] = metadata
 
-                self.dirty = True
-                self.damage(coords)
-        except IndexError:
-            # Coordinates were out-of-bounds; warn.
-            warn("Coordinates %s are out-of-bounds in %s" % (coords, self),
-                 ChunkWarning)
+            self.dirty = True
+            self.damage(coords)
 
+    @check_bounds
     def destroy(self, coords):
         """
         Destroy the block at the given coordinates.
