@@ -10,6 +10,10 @@ from bravo.location import Location
 from bravo.beta.packets import make_packet
 from bravo.utilities.coords import split_coords
 from bravo.utilities.geometry import gen_close_point
+from bravo.utilities.maths import clamp
+from bravo.utilities.furnace import (furnace_recipes, furnace_on_off,
+    update_all_windows_slot, update_all_windows_progress)
+from bravo.blocks import furnace_fuel, unstackable
 
 class Entity(object):
     """
@@ -63,6 +67,12 @@ class Player(Entity):
 
         self.equipped = 0
 
+    def __repr__(self):
+        return ("%s(eid=%d, location=%s, username=%s)" %
+                (self.name, self.eid, self.location, self.username))
+
+    __str__ = __repr__
+
     def save_to_packet(self):
         """
         Create a "player" packet representing this entity.
@@ -189,28 +199,51 @@ class Mob(Entity):
     """
     A creature.
     """
+
+    name = "Mob"
+    """
+    The name of this mob.
+
+    Names are used to identify mobs during serialization, just like for all
+    other entities.
+
+    This mob might not be serialized if this name is not overriden.
+    """
+
+    metadata = {0: ("byte", 0)}
+
     def __init__(self, **kwargs):
         """
-        Create a mob
+        Create a mob.
 
         This method calls super().
         """
+
         self.loop = None
         super(Mob, self).__init__(**kwargs)
         self.manager = None
 
-    name = "Mob"
-    type = "mob"
+    def update_metadata(self):
+        """
+        Overrideable hook for general metadata updates.
 
-    metadata = {0: ("byte", 0)}
+        This method is necessary because metadata generally only needs to be
+        updated prior to certain events, not necessarily in response to
+        external events.
+
+        This hook will always be called prior to saving this mob's data for
+        serialization or wire transfer.
+        """
 
     def run(self):
         """
         Starts a mob's loop process
         """
+
         xcoord, chaff, zcoord, chaff = split_coords(self.location.x,
             self.location.z)
-        self.chunk_coords = (xcoord,1, zcoord) # XXX The one is redundant, fix it
+        # XXX The one is redundant, fix it
+        self.chunk_coords = xcoord, 1, zcoord
         self.loop = LoopingCall(self.update)
         self.loop.start(.2)
 
@@ -219,9 +252,12 @@ class Mob(Entity):
         Create a "mob" packet representing this entity.
         """
 
+        # Update metadata from instance variables.
+        self.update_metadata()
+
         return make_packet("mob",
             eid=self.eid,
-            type=self.type,
+            type=self.name,
             x=self.location.x * 32 + 16,
             y=self.location.y * 32,
             z=self.location.z * 32 + 16,
@@ -244,7 +280,7 @@ class Mob(Entity):
         """
         Update this mob's location with respect to a factory.
         """
-        clamp = lambda n: max(min(.4, n), -.4)
+
         # XXX  Discuss appropriate style with MAD
         player = self.manager.closest_player((self.location.x,
                                  self.location.y,
@@ -267,9 +303,11 @@ class Mob(Entity):
             self_pos = (self.location.x, self.location.y, self.location.z)
             vector = gen_close_point(self_pos, target)
 
-            vector = (clamp(vector[0]),
-                clamp(vector[1]),
-                clamp(vector[2]))
+            vector = (
+                clamp(vector[0], -0.4, 0.4),
+                clamp(vector[1], -0.4, 0.4),
+                clamp(vector[2], -0.4, 0.4),
+            )
 
         new_position = (vector[0] + self.location.x,
             vector[1] + self.location.y,
@@ -305,7 +343,6 @@ class Chuck(Mob):
     """
 
     name = "Chicken"
-    type = "chuck"
     offsetlist = ((.5, 0, .5),
             (-.5, 0, .5),
             (.5, 0, -.5),
@@ -317,7 +354,6 @@ class Cow(Mob):
     """
 
     name = "Cow"
-    type = "cow"
 
 class Creeper(Mob):
     """
@@ -326,8 +362,6 @@ class Creeper(Mob):
 
     name = "Creeper"
 
-    metadata = {0: ("byte", 0), 17: ("byte", 0)}
-
     def __init__(self, aura=False, **kwargs):
         """
         Create a creeper.
@@ -339,40 +373,25 @@ class Creeper(Mob):
 
         self.aura = aura
 
-    def save_to_packet(self):
-        metadata = self.metadata.copy()
-
-        aura = 0
-        if self.aura:
-            aura |= 0x1
-        metadata[17] = "byte", aura
-
-        return make_packet("mob",
-            eid=self.eid,
-            type="creeper",
-            x=self.location.x * 32 + 16,
-            y=self.location.y * 32,
-            z=self.location.z * 32 + 16,
-            yaw=0,
-            pitch=0,
-            metadata=metadata
-        )
+    def update_metadata(self):
+        self.metadata = {
+            0: ("byte", 0),
+            17: ("byte", int(self.aura)),
+        }
 
 class Ghast(Mob):
     """
-    A sad ghost
+    A very melancholy ghost.
     """
 
     name = "Ghast"
-    type = "ghast"
 
 class GiantZombie(Mob):
     """
-    A giant zombie
+    Like a regular zombie, but far larger.
     """
 
     name = "GiantZombie"
-    type = "giant_zombie"
 
 class Pig(Mob):
     """
@@ -381,52 +400,37 @@ class Pig(Mob):
 
     name = "Pig"
 
-    metadata = {0: ("byte", 0), 16: ("byte", 0)}
-
     def __init__(self, saddle=False, **kwargs):
         """
         Create a pig.
 
-        This method calls super()
+        This method calls super().
         """
 
         super(Pig, self).__init__(**kwargs)
 
         self.saddle = saddle
 
-    def save_to_packet(self):
-        # Prepare metadata.
-        metadata = self.metadata.copy()
-        metadata[16] = "byte", self.saddle
+    def update_metadata(self):
+        self.metadata = {
+            0: ("byte", 0),
+            16: ("byte", int(self.saddle)),
+        }
 
-        return make_packet("mob",
-            eid=self.eid,
-            type="pig",
-            x=self.location.x * 32 + 16,
-            y=self.location.y * 32,
-            z=self.location.z * 32 + 16,
-            yaw=0,
-            pitch=0,
-            metadata=metadata
-        )
-
-class PigZombie(Mob):
+class ZombiePigman(Mob):
     """
     A zombie pigman.
     """
 
     name = "PigZombie"
-    type = "pigman"
 
 class Sheep(Mob):
     """
-    A wooly mob.
+    A woolly mob.
     """
 
     name = "Sheep"
 
-    metadata = {0: ("byte", 0), 16: ("byte", 0)}
-
     def __init__(self, sheared=False, color=0, **kwargs):
         """
         Create a sheep.
@@ -439,24 +443,15 @@ class Sheep(Mob):
         self.sheared = sheared
         self.color = color
 
-    def save_to_packet(self):
-        # Prepare metadata.
-        metadata = self.metadata.copy()
+    def update_metadata(self):
         color = self.color
         if self.sheared:
             color |= 0x10
-        metadata[16] = "byte", color
 
-        return make_packet("mob",
-            eid=self.eid,
-            type="sheep",
-            x=self.location.x * 32 + 16,
-            y=self.location.y * 32,
-            z=self.location.z * 32 + 16,
-            yaw=0,
-            pitch=0,
-            metadata=metadata
-        )
+        self.metadata = {
+            0: ("byte", 0),
+            16: ("byte", color),
+        }
 
 class Skeleton(Mob):
     """
@@ -464,7 +459,6 @@ class Skeleton(Mob):
     """
 
     name = "Skeleton"
-    type = "skeleton"
 
 class Slime(Mob):
     """
@@ -473,8 +467,6 @@ class Slime(Mob):
 
     name = "Slime"
 
-    metadata = {0: ("byte", 0), 16: ("byte", 0)}
-
     def __init__(self, size=1, **kwargs):
         """
         Create a slime.
@@ -486,21 +478,11 @@ class Slime(Mob):
 
         self.size = size
 
-    def save_to_packet(self):
-        # Prepare metadata.
-        metadata = self.metadata.copy()
-        metadata[16] = "byte", self.size
-
-        return make_packet("mob",
-            eid=self.eid,
-            type="slime",
-            x=self.location.x * 32 + 16,
-            y=self.location.y * 32,
-            z=self.location.z * 32 + 16,
-            yaw=0,
-            pitch=0,
-            metadata=metadata
-        )
+    def update_metadata(self):
+        self.metadata = {
+            0: ("byte", 0),
+            16: ("byte", self.size),
+        }
 
 class Spider(Mob):
     """
@@ -508,7 +490,6 @@ class Spider(Mob):
     """
 
     name = "Spider"
-    type = "spider"
 
 class Squid(Mob):
     """
@@ -516,7 +497,6 @@ class Squid(Mob):
     """
 
     name = "Squid"
-    type = "squid"
 
 class Wolf(Mob):
     """
@@ -525,8 +505,6 @@ class Wolf(Mob):
 
     name = "Wolf"
 
-    metadata = {0: ("byte", 0), 16: ("byte", 0)}
-
     def __init__(self, owner=None, angry=False, sitting=False, **kwargs):
         """
         Create a wolf.
@@ -540,28 +518,19 @@ class Wolf(Mob):
         self.angry = angry
         self.sitting = sitting
 
-    def save_to_packet(self):
-        # Prepare metadata.
-        metadata = self.metadata.copy()
-        props = 0
+    def update_metadata(self):
+        flags = 0
         if self.sitting:
-            props |= 0x1
+            flags |= 0x1
         if self.angry:
-            props |= 0x2
+            flags |= 0x2
         if self.owner:
-            props |= 0x4
-        metadata[16] = "byte", props
+            flags |= 0x4
 
-        return make_packet("mob",
-            eid=self.eid,
-            type="wolf",
-            x=self.location.x * 32 + 16,
-            y=self.location.y * 32,
-            z=self.location.z * 32 + 16,
-            yaw=0,
-            pitch=0,
-            metadata=metadata
-        )
+        self.metadata = {
+            0: ("byte", 0),
+            16: ("byte", flags),
+        }
 
 class Zombie(Mob):
     """
@@ -569,8 +538,8 @@ class Zombie(Mob):
     """
 
     name = "Zombie"
-    type = "zombie"
     offsetlist = ((-.5,0,-.5), (-.5,0,.5), (.5,0,-.5), (.5,0,.5), (-.5,1,-.5), (-.5,1,.5), (.5,1,-.5), (.5,1,.5),)
+
 entities = dict((entity.name, entity)
     for entity in (
         Chuck,
@@ -581,7 +550,6 @@ entities = dict((entity.name, entity)
         Painting,
         Pickup,
         Pig,
-        PigZombie,
         Player,
         Sheep,
         Skeleton,
@@ -590,6 +558,7 @@ entities = dict((entity.name, entity)
         Squid,
         Wolf,
         Zombie,
+        ZombiePigman,
     )
 )
 
@@ -636,12 +605,171 @@ class Furnace(Tile):
 
     name = "Furnace"
 
+    burntime = 0
+    cooktime = 0
+    running = False
+
     def __init__(self, *args, **kwargs):
         super(Furnace, self).__init__(*args, **kwargs)
 
-        self.burntime = 0
-        self.cooktime = 0
         self.inventory = FurnaceStorage()
+        self.burning = LoopingCall.withCount(self.burn)
+
+    def changed(self, factory, coords):
+        '''
+        Called from outside by event handler to inform the tile
+        that the content was changed. If the furnace meet the requirements
+        the method starts ``burn`` process. The ``burn`` stops the
+        looping call when it's out of fuel or no need to burn more.
+
+        We get furnace coords from outer side as the tile does not know
+        about own chunk. If self.chunk is implemented the parameter
+        can be removed and self.coords will be:
+
+        >>> self.coords = self.chunk.x, self.x, self.chunk.z, self.z, self.y
+
+        :param `BravoFactory` factory: The factory
+        :param tuple coords: (bigx, smallx, bigz, smallz, y) - coords of this furnace
+        '''
+
+        self.coords = coords
+        self.factory = factory
+
+        if not self.running:
+            if self.burntime != 0:
+                # This furnace was already burning, but not started. This
+                # usually means that the furnace was serialized while burning.
+                self.running = True
+                self.burn_max = self.burntime
+                self.burning.start(0.5)
+            elif self.has_fuel() and self.can_craft():
+                # This furnace could be burning, but isn't. Let's start it!
+                self.burntime = 0
+                self.cooktime = 0
+                self.burning.start(0.5)
+
+    def burn(self, ticks):
+        '''
+        The main furnace loop.
+
+        :param int ticks: number of furnace iterations to perform
+        '''
+
+        # Usually it's only one iteration but if something blocks the server
+        # for long period we shall process skipped ticks.
+        # Note: progress bars will lag anyway.
+        if ticks > 1:
+            log.msg("Lag detected; skipping %d furnace ticks" % (ticks - 1))
+
+        for iteration in xrange(ticks):
+            # Craft items, if we can craft them.
+            if self.can_craft():
+                self.cooktime += 1
+
+                # Notchian time is ~9.25-9.50 sec.
+                if self.cooktime == 20:
+                    # Looks like things were successfully crafted.
+                    source = self.inventory.crafting[0]
+                    product = furnace_recipes[source.primary]
+                    self.inventory.crafting[0] = source.decrement()
+
+                    if self.inventory.crafted[0] is None:
+                        self.inventory.crafted[0] = product
+                    else:
+                        item = self.inventory.crafted[0]
+                        self.inventory.crafted[0] = item.increment(product.quantity)
+
+                    update_all_windows_slot(self.factory, self.coords, 0, self.inventory.crafting[0])
+                    update_all_windows_slot(self.factory, self.coords, 2, self.inventory.crafted[0])
+                    self.cooktime = 0
+            else:
+                self.cooktime = 0
+
+            # Consume fuel, if applicable.
+            if self.burntime == 0:
+                if self.has_fuel() and self.can_craft():
+                    # We have fuel and stuff to craft, so burn a bit of fuel
+                    # and craft some stuff.
+                    fuel = self.inventory.fuel[0]
+                    self.burntime = self.burn_max = furnace_fuel[fuel.primary]
+                    self.inventory.fuel[0] = fuel.decrement()
+
+                    if not self.running:
+                        self.running = True
+                        furnace_on_off(self.factory, self.coords, True)
+
+                    update_all_windows_slot(self.factory, self.coords, 1, self.inventory.fuel[0])
+                else:
+                    # We're finished burning. Turn ourselves off.
+                    self.burning.stop()
+                    self.running = False
+                    furnace_on_off(self.factory, self.coords, False)
+
+                    # Reset the cooking time, just because.
+                    self.cooktime = 0
+                    update_all_windows_progress(self.factory, self.coords, 0, 0)
+                    return
+
+            self.burntime -= 1
+
+        # Update progress bars for the window.
+        # XXX magic numbers
+        cook_progress = 185 * self.cooktime / 19
+        burn_progress = 250 * self.burntime / self.burn_max
+        update_all_windows_progress(self.factory, self.coords, 0, cook_progress)
+        update_all_windows_progress(self.factory, self.coords, 1, burn_progress)
+
+    def has_fuel(self):
+        '''
+        Determine whether this furnace is fueled.
+
+        :returns: bool
+        '''
+
+        return (self.inventory.fuel[0] is not None and
+                self.inventory.fuel[0].primary in furnace_fuel)
+
+    def can_craft(self):
+        '''
+        Determine whether this furnace is capable of outputting items.
+
+        Note that this is independent of whether the furnace is fueled.
+
+        :returns: bool
+        '''
+
+        crafting = self.inventory.crafting[0]
+        crafted = self.inventory.crafted[0]
+
+        # Nothing to craft?
+        if crafting is None:
+            return False
+
+        # No matching recipe?
+        if crafting.primary not in furnace_recipes:
+            return False
+
+        # Something to craft and no current output? This is a success
+        # condition.
+        if crafted is None:
+            return True
+
+        # Unstackable output?
+        if crafted.primary in unstackable:
+            return False
+
+        recipe = furnace_recipes[crafting.primary]
+
+        # Recipe doesn't match current output?
+        if recipe[0] != crafted.primary:
+            return False
+
+        # Crafting would overflow current output?
+        if crafted.quantity + recipe.quantity > 64:
+            return False
+
+        # By default, yes, you can craft.
+        return True
 
 class MobSpawner(Tile):
     """
