@@ -230,6 +230,18 @@ class ISerializer(IBravoPlugin):
     implementation of their serialization technique.
     """
 
+    def connect(url):
+        """
+        Connect this serializer to a serialization resource, as defined in
+        ``url``.
+
+        Bravo uses URLs to specify all serialization resources. While there is
+        no strict enforcement of the identifier being a URL, most popular
+        database libraries can understand URL-based resources, and thus it is
+        a useful *de facto* standard. If a URL is not passed, or the URL is
+        invalid, this method may raise an exception.
+        """
+
     def save_chunk(chunk):
         """
         Save a chunk.
@@ -239,9 +251,11 @@ class ISerializer(IBravoPlugin):
 
     def load_chunk(chunk):
         """
-        Load a chunk.
+        Load a chunk. The chunk must exist.
 
         May return a ``Deferred`` that will fire on completion.
+
+        :raises: SerializerReadException if the chunk doesn't exist
         """
 
     def save_level(level):
@@ -253,9 +267,11 @@ class ISerializer(IBravoPlugin):
 
     def load_level(level):
         """
-        Load a level.
+        Load a level. The level must exist.
 
         May return a ``Deferred`` that will fire on completion.
+
+        :raises: SerializerReadException if the level doesn't exist
         """
 
     def save_player(player):
@@ -267,32 +283,28 @@ class ISerializer(IBravoPlugin):
 
     def load_player(player):
         """
-        Load a player.
+        Load a player. The player must exist.
+
+        May return a ``Deferred`` that will fire on completion.
+
+        :raises: SerializerReadException if the player doesn't exist
+        """
+
+    def save_plugin_data(name, value):
+        """
+        Save plugin-specific data. The data must be a bytestring.
 
         May return a ``Deferred`` that will fire on completion.
         """
 
     def load_plugin_data(name):
         """
-        Load plugin-specific data.
+        Load plugin-specific data. If no data is found, an empty bytestring
+        will be returned.
 
         May return a ``Deferred`` that will fire on completion.
         """
 
-    def save_plugin_data(name, value):
-        """
-        Save plugin-specific data.
-
-        May return a ``Deferred`` that will fire on completion.
-        """
-
-class ISerializerFactory(IBravoPlugin):
-    """
-    Factory for ``ISerializer`` instances.
-
-    I am so sorry for this.
-    """
-
 # Hooks
 
 class IWindowOpenHook(ISortedPlugin):
