@@ -3,7 +3,7 @@ from math import cos, degrees, radians, pi, sin, sqrt
 
 from construct import Container
 
-from bravo.packets.beta import make_packet
+from bravo.beta.packets import make_packet
 
 class Location(object):
     """
