@@ -2,12 +2,11 @@ import random
 import sys
 
 from twisted.internet import reactor
-from twisted.internet.defer import succeed, fail
+from twisted.internet.defer import succeed
 from twisted.internet.task import deferLater
 from twisted.web.client import getPage
 from zope.interface import implements
 
-from bravo.config import configuration
 from bravo.ibravo import IAuthenticator
 from bravo.beta.packets import make_packet
 
@@ -35,10 +34,12 @@ class OfflineAuthenticator(object):
     def login(self, protocol, container):
         protocol.username = container.username
 
+        players = min(protocol.factory.limitConnections, 60)
+
         packet = make_packet("login", protocol=protocol.eid, username="",
             seed=protocol.factory.world.seed, mode=protocol.factory.mode,
             dimension=protocol.factory.world.dimension, unknown=1, height=128,
-            players=0)
+            players=players)
         protocol.transport.write(packet)
 
         return succeed(None)
@@ -91,10 +92,12 @@ class OnlineAuthenticator(object):
             protocol.error("Authentication server didn't like you.")
             return
 
+        players = min(protocol.factory.limitConnections, 60)
+
         packet = make_packet("login", protocol=protocol.eid, username="",
             seed=protocol.factory.world.seed, mode=protocol.factory.mode,
             dimension=protocol.factory.world.dimension, unknown=1, height=128,
-            players=0)
+            players=players)
         protocol.transport.write(packet)
 
     def error(self, description, protocol):
@@ -103,44 +106,5 @@ class OnlineAuthenticator(object):
 
     name = "online"
 
-class PasswordAuthenticator(object):
-
-    implements(IAuthenticator)
-
-    def handshake(self, protocol, container):
-        """
-        Handle a handshake with a server-specific password.
-
-        This doesn't work with Notchian clients.
-        """
-
-        packet = make_packet("handshake", username="+")
-
-        # Order is important here; the challenged callback *must* fire before
-        # we send anything back to the client, because otherwise we won't have
-        # a valid entity ready to use.
-        d = deferLater(reactor, 0, protocol.challenged)
-        d.addCallback(lambda none: protocol.transport.write(packet))
-
-        return True
-
-    def login(self, protocol, container):
-        if container.password != configuration.get("bravo", "password"):
-            protocol.error("Wrong password.")
-            return fail()
-
-        protocol.username = container.username
-
-        packet = make_packet("login", protocol=protocol.eid, username="",
-            seed=protocol.factory.world.seed, mode=protocol.factory.mode,
-            dimension=protocol.factory.world.dimension, unknown=1, height=128,
-            players=0)
-        protocol.transport.write(packet)
-
-        return succeed(None)
-
-    name = "password"
-
 offline = OfflineAuthenticator()
 online = OnlineAuthenticator()
-password = PasswordAuthenticator()
