@@ -1,19 +1,27 @@
 from itertools import product
 from StringIO import StringIO
+import os
+import time
 
 from PIL import Image
 
 from twisted.web.resource import Resource
 from twisted.web.server import NOT_DONE_YET
-from twisted.web.template import flattenString, renderer, tags, Element, XMLString
+from twisted.web.template import flattenString, renderer, Element
+from twisted.web.template import XMLString, XMLFile
+from twisted.web.http import datetimeToString
 
 from zope.interface import implements
 
 from bravo.blocks import blocks
 from bravo.ibravo import IWorldResource
+from bravo import __file__
 
 from bravo.parameters import factory
 
+worldmap_xml = os.path.join(os.path.dirname(__file__), 'plugins',
+                            'worldmap.html')
+
 block_colors = {
     blocks["clay"].slot: "rosybrown",
     blocks["cobblestone"].slot: 'dimgray',
@@ -64,6 +72,11 @@ class ChunkIllustrator(Resource):
         self.z = z
 
     def _cb_render_GET(self, chunk, request):
+        # If the request finished already, then don't even bother preparing
+        # the image.
+        if request._disconnected:
+            return
+
         request.setHeader('content-type', 'image/png')
         i = Image.new("RGB", (16, 16))
         pbo = i.load()
@@ -81,7 +94,9 @@ class ChunkIllustrator(Resource):
 
         data = StringIO()
         i.save(data, "PNG")
-
+        # cache image for 5 minutes
+        request.setHeader("Cache-Control", "public, max-age=360")
+        request.setHeader("Expires", datetimeToString(time.time() + 360))
         request.write(data.getvalue())
         request.finish()
 
@@ -90,35 +105,12 @@ class ChunkIllustrator(Resource):
         d.addCallback(self._cb_render_GET, request)
         return NOT_DONE_YET
 
-world_map_template = """
-<html xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1">
-    <head>
-        <title>WorldMap</title>
-    </head>
-    <body>
-        <h1>WorldMap</h1>
-        <div nowrap="nowrap" t:render="main" />
-    </body>
-</html>
-"""
-
 class WorldMapElement(Element):
     """
     Element for the WorldMap plugin.
     """
 
-    loader = XMLString(world_map_template)
-
-    @renderer
-    def main(self, request, tag):
-        path = request.URLPath()
-        l = []
-        for y in range(-5, 5):
-            for x in range(-5, 5):
-                child = path.child("%s,%s" % (x, y))
-                l.append(tags.img(src=str(child), height="64", width="64"))
-            l.append(tags.br())
-        return tag(*l)
+    loader = XMLFile(worldmap_xml)
 
 class WorldMap(Resource):
 
@@ -143,8 +135,9 @@ class WorldMap(Resource):
     def render_GET(self, request):
         d = flattenString(request, self.element)
         def complete_request(html):
-            request.write(html)
-            request.finish()
+            if not request._disconnected:
+                request.write(html)
+                request.finish()
         d.addCallback(complete_request)
         return NOT_DONE_YET
 
@@ -160,6 +153,52 @@ automaton_stats_template = """
 </html>
 """
 
+class AutomatonElement(Element):
+    """
+    An automaton.
+    """
+
+    loader = XMLString("""
+        <div xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1">
+            <h2 t:render="name" />
+            <ul>
+                <li t:render="tracked" />
+                <li t:render="step" />
+            </ul>
+        </div>
+    """)
+
+    def __init__(self, automaton):
+        Element.__init__(self)
+        self.automaton = automaton
+
+    @renderer
+    def name(self, request, tag):
+        return tag(self.automaton.name)
+
+    @renderer
+    def tracked(self, request, tag):
+        if hasattr(self.automaton, "tracked"):
+            t = self.automaton.tracked
+            if isinstance(t, dict):
+                l = sum(len(i) for i in t.values())
+            else:
+                l = len(t)
+            s = "Currently tracking %d blocks" % l
+        else:
+            s = "<n/a>"
+
+        return tag(s)
+
+    @renderer
+    def step(self, request, tag):
+        if hasattr(self.automaton, "step"):
+            s = "Currently processing every %f seconds" % self.automaton.step
+        else:
+            s = "<n/a>"
+
+        return tag(s)
+
 class AutomatonStatsElement(Element):
     """
     Render some information about automatons.
@@ -169,26 +208,7 @@ class AutomatonStatsElement(Element):
 
     @renderer
     def main(self, request, tag):
-        retval = []
-        for automaton in factory.automatons:
-            title = tags.h2(automaton.name)
-            stats = []
-
-            # Discover tracked information.
-            if hasattr(automaton, "tracked"):
-                t = automaton.tracked
-                if isinstance(t, dict):
-                    l = sum(len(i) for i in t.values())
-                else:
-                    l = len(t)
-                stats.append(tags.li("Currently tracking %d blocks" % l))
-
-            if hasattr(automaton, "step"):
-                stats.append(tags.li("Currently processing every %f seconds" %
-                    automaton.step))
-
-            retval.append(tags.div(title, tags.ul(stats)))
-        return tags.div(*retval)
+        return tag(*(AutomatonElement(a) for a in factory.automatons))
 
 class AutomatonStats(Resource):
 
@@ -201,8 +221,9 @@ class AutomatonStats(Resource):
     def render_GET(self, request):
         d = flattenString(request, AutomatonStatsElement())
         def complete_request(html):
-            request.write(html)
-            request.finish()
+            if not request._disconnected:
+                request.write(html)
+                request.finish()
         d.addCallback(complete_request)
         return NOT_DONE_YET
 
