@@ -85,7 +85,7 @@ def is_effective_against(block, slot):
             blocks["brimstone"].slot,
             blocks["coal-ore"].slot,
             blocks["cobblestone"].slot,
-            blocks["diamond"].slot,
+            blocks["diamond-block"].slot,
             blocks["diamond-ore"].slot,
             blocks["double-step"].slot,
             blocks["gold"].slot,
@@ -93,7 +93,7 @@ def is_effective_against(block, slot):
             blocks["ice"].slot,
             blocks["iron"].slot,
             blocks["iron-ore"].slot,
-            blocks["lapis-lazuli"].slot,
+            blocks["lapis-lazuli-block"].slot,
             blocks["lapis-lazuli-ore"].slot,
             blocks["mossy-cobblestone"].slot,
             blocks["sandstone"].slot,
@@ -119,9 +119,9 @@ class NotchyDigPolicy(object):
             blocks["redstone-torch"].slot,
             blocks["redstone-torch-off"].slot,
             blocks["redstone-wire"].slot,
+            blocks["reed"].slot,
             blocks["rose"].slot,
             blocks["sapling"].slot,
-            blocks["sugar-cane"].slot,
             blocks["tnt"].slot,
             blocks["torch"].slot,
             ):
