@@ -38,6 +38,14 @@ class TestBlockQuirks(unittest.TestCase):
     def test_grass_secondary(self):
         self.assertEqual(blocks["grass"].key[1], 0)
 
+    def test_lever_extra_valid_metadata(self):
+        self.assertEqual(blocks["lever"].face(5), blocks["lever"].face(13))
+
+    def test_pumpkin_stem_drops(self):
+        self.assertEqual(blocks["pumpkin-stem"].drop,
+            items["pumpkin-seeds"].key)
+        self.assertEqual(blocks["pumpkin-stem"].quantity, 3)
+
 class TestParseBlock(unittest.TestCase):
 
     def test_parse_block(self):
