@@ -4,12 +4,13 @@ import warnings
 from numpy import empty
 from numpy.testing import assert_array_equal
 
-import bravo.chunk
+from bravo.blocks import blocks
+from bravo.chunk import Chunk
 
 class TestChunkBlocks(unittest.TestCase):
 
     def setUp(self):
-        self.c = bravo.chunk.Chunk(0, 0)
+        self.c = Chunk(0, 0)
 
     def test_trivial(self):
         pass
@@ -58,7 +59,7 @@ class TestChunkBlocks(unittest.TestCase):
         self.assertEqual(self.c.get_block((3, 3, 3)), 3)
 
     def test_single_block_damage_packet(self):
-        chunk = bravo.chunk.Chunk(2, 1)
+        chunk = Chunk(2, 1)
         chunk.populated = True
         chunk.set_block((2, 4, 8), 1)
         chunk.set_metadata((2, 4, 8), 2)
@@ -98,7 +99,7 @@ class TestNumpyQuirks(unittest.TestCase):
 
     def test_get_damage_packet_single(self):
         # Create a chunk.
-        c = bravo.chunk.Chunk(0, 0)
+        c = Chunk(0, 0)
         # Damage the block.
         c.populated = True
         c.set_block((0, 0, 0), 1)
@@ -112,7 +113,7 @@ class TestNumpyQuirks(unittest.TestCase):
 
     def test_get_damage_packet_batch(self):
         # Create a chunk.
-        c = bravo.chunk.Chunk(0, 0)
+        c = Chunk(0, 0)
         # Damage the block so that it will generate a multi-block batch
         # packet.
         c.populated = True
@@ -129,7 +130,7 @@ class TestNumpyQuirks(unittest.TestCase):
 class TestLightmaps(unittest.TestCase):
 
     def setUp(self):
-        self.c = bravo.chunk.Chunk(0, 0)
+        self.c = Chunk(0, 0)
 
     def test_trivial(self):
         pass
@@ -233,3 +234,34 @@ class TestLightmaps(unittest.TestCase):
         self.c.regenerate()
 
         self.assertEqual(self.c.skylight[1, 1, 1], 12)
+
+    def test_incremental_solid(self):
+        """
+        Regeneration isn't necessary to correctly light solid blocks.
+        """
+
+        # Initialize tables and enable set_block().
+        self.c.regenerate()
+        self.c.populated = True
+
+        # Any solid block with no dimming works. I choose dirt.
+        self.c.set_block((0, 0, 0), blocks["dirt"].slot)
+
+        self.assertEqual(self.c.skylight[0, 0, 0], 0)
+
+    def test_incremental_air(self):
+        """
+        Regeneration isn't necessary to correctly light dug blocks, which
+        leave behind air.
+        """
+
+        # Any solid block with no dimming works. I choose dirt.
+        self.c.blocks[0, 0, 0] = blocks["dirt"].slot
+
+        # Initialize tables and enable set_block().
+        self.c.regenerate()
+        self.c.populated = True
+
+        self.c.set_block((0, 0, 0), blocks["air"].slot)
+
+        self.assertEqual(self.c.skylight[0, 0, 0], 15)
