@@ -1,11 +1,11 @@
 import unittest
 
-from bravo.simplex import reseed, simplex, octaves2, octaves3
+from bravo.simplex import set_seed, simplex, octaves2, octaves3
 
 class TestOctaves(unittest.TestCase):
 
     def setUp(self):
-        reseed(0)
+        set_seed(0)
 
     def test_trivial(self):
         pass
