@@ -8,8 +8,8 @@ import tempfile
 
 from itertools import product
 
-import bravo.config
-from bravo.errors import ChunkNotLoaded, SerializerReadException
+from bravo.config import BravoConfigParser
+from bravo.errors import ChunkNotLoaded
 from bravo.world import World
 
 class TestWorldChunks(unittest.TestCase):
@@ -17,22 +17,19 @@ class TestWorldChunks(unittest.TestCase):
     def setUp(self):
         self.name = "unittest"
         self.d = tempfile.mkdtemp()
+        self.bcp = BravoConfigParser()
 
-        bravo.config.configuration.add_section("world unittest")
-        bravo.config.configuration.set("world unittest", "url", "file://%s" % self.d)
-        bravo.config.configuration.set("world unittest", "serializer",
-            "alpha")
+        self.bcp.add_section("world unittest")
+        self.bcp.set("world unittest", "url", "file://%s" % self.d)
+        self.bcp.set("world unittest", "serializer", "alpha")
 
-        self.w = World(self.name)
+        self.w = World(self.bcp, self.name)
         self.w.pipeline = []
         self.w.start()
 
     def tearDown(self):
         self.w.stop()
-        del self.w
-
         shutil.rmtree(self.d)
-        bravo.config.configuration.remove_section("world unittest")
 
     def test_trivial(self):
         pass
@@ -61,7 +58,7 @@ class TestWorldChunks(unittest.TestCase):
             dtype=numpy.uint8)
         chunk.metadata.shape = (16, 16, 128)
 
-        for x, y, z in product(xrange(2), xrange(2), xrange(2)):
+        for x, y, z in product(xrange(2), repeat=3):
             # This works because the chunk is at (0, 0) so the coords don't
             # need to be adjusted.
             metadata = yield self.w.get_metadata((x, y, z))
@@ -83,7 +80,7 @@ class TestWorldChunks(unittest.TestCase):
         self.w.dirty_chunk_cache.clear()
         chunk = yield self.w.request_chunk(0, 0)
 
-        for x, y, z in product(xrange(2), xrange(2), xrange(2)):
+        for x, y, z in product(xrange(2), repeat=3):
             # This works because the chunk is at (0, 0) so the coords don't
             # need to be adjusted.
             block = yield self.w.get_block((x, y, z))
@@ -105,7 +102,7 @@ class TestWorldChunks(unittest.TestCase):
         self.w.dirty_chunk_cache.clear()
         chunk = yield self.w.request_chunk(-1, -1)
 
-        for x, y, z in product(xrange(2), xrange(2), xrange(2)):
+        for x, y, z in product(xrange(2), repeat=3):
             block = yield self.w.get_block((x - 16, y, z - 16))
             self.assertEqual(block, chunk.get_block((x, y, z)))
 
@@ -125,7 +122,7 @@ class TestWorldChunks(unittest.TestCase):
         self.w.dirty_chunk_cache.clear()
         chunk = yield self.w.request_chunk(0, 0)
 
-        for x, y, z in product(xrange(2), xrange(2), xrange(2)):
+        for x, y, z in product(xrange(2), repeat=3):
             # This works because the chunk is at (0, 0) so the coords don't
             # need to be adjusted.
             metadata = yield self.w.get_metadata((x, y, z))
@@ -198,35 +195,38 @@ class TestWorldChunks(unittest.TestCase):
 
         return d
 
-class TestWorldInit(unittest.TestCase):
+class TestWorld(unittest.TestCase):
 
     def setUp(self):
         self.name = "unittest"
         self.d = tempfile.mkdtemp()
+        self.bcp = BravoConfigParser()
 
-        bravo.config.configuration.add_section("world unittest")
-        bravo.config.configuration.set("world unittest", "url", "file://%s" % self.d)
-        bravo.config.configuration.set("world unittest", "serializer",
-            "alpha")
+        self.bcp.add_section("world unittest")
+        self.bcp.set("world unittest", "url", "file://%s" % self.d)
+        self.bcp.set("world unittest", "serializer", "alpha")
+
+        self.w = World(self.bcp, self.name)
+        self.w.pipeline = []
+        self.w.start()
 
     def tearDown(self):
+        self.w.stop()
         shutil.rmtree(self.d)
-        bravo.config.configuration.remove_section("world unittest")
 
     def test_trivial(self):
         pass
 
-    def test_load_level_exception(self):
+    def test_load_player_initial(self):
         """
-        Exceptions raised during serializer reads should be handled during the
-        world startup.
+        Calling load_player() on a player which has never been loaded should
+        not result in an exception. Instead, the player should be returned,
+        wrapped in a Deferred.
         """
 
-        from bravo.plugins.serializers import Alpha
-        def raiser(self, level):
-            raise SerializerReadException("testing")
-        self.patch(Alpha, "load_level", raiser)
-
-        w = bravo.world.World(self.name)
-        w.start()
-        w.stop()
+        # For bonus points, assert that the player's username is correct.
+        d = self.w.load_player("unittest")
+        @d.addCallback
+        def cb(player):
+            self.assertEqual(player.username, "unittest")
+        return d
