@@ -1,67 +1,58 @@
+"""
+Simple pixel graphics helpers.
+"""
 
-def gen_close_point(point1, point2): # XXX This needs to be optimized
-    """
-    Generalization of Bresenham's line algorithm in 3d.
-
-    It returns the first block's coordinates in a one block wide line from
-    point1 to point2
-
-    It is a simplified version that does nothing fancy with integers or such:
-    all computation is done on float (maybe it should be changed?)
-    """
-
-    tx, ty, tz = point1 # t is for temporary
-    ox, oy, oz = point2 # o is for objective
-
-    dx = ox - tx
-    dy = oy - ty
-    dz = oz - tz
-    if (dx,dy,dz) == (0,0,0):
-        return (0,0,0)
-
-    largest = max (abs (dx), abs (dy), abs (dz)) * 1. # We want a float
-    dx, dy, dz = dx / largest, dy / largest, dz / largest # We make a vector which maximum value is 1.0
-
-    while abs (ox - tx) > 1 or abs (oy - ty) > 1 or abs (oz - tz) > 1:
-        tx += dx
-        ty += dy
-        tz += dz
-        if (ty < 0 and dy < 0) or (ty >= 127 and dy > 0):
-            return (0,0,0)
-            break
-
-        return(dx,dy,dz)
-    return (0,0,0)
 def gen_line_simple(point1, point2):
     """
-    Generalization of Bresenham's line algorithm in 3d.
+    An adaptation of Bresenham's line algorithm in three dimensions.
 
-    It yields blocks coordinates along a line that is at all times only one
-    block in width.
-
-    It is a simplified version that does nothing fancy with integers or such:
-    all computation is done on float (maybe it should be changed?)
+    This function returns an iterable of integer coordinates along the line
+    from the first point to the second point. No points are omitted.
     """
 
+    # XXX should be done with ints instead of floats
+
     tx, ty, tz = point1.x, point1.y, point1.z # t is for temporary
-    rx, ry, rz = int (tx), int (ty), int (tz) # r is for rounded
+    rx, ry, rz = int(tx), int(ty), int(tz) # r is for rounded
     ox, oy, oz = point2.x, point2.y, point2.z # o is for objective
 
     dx = ox - tx
     dy = oy - ty
     dz = oz - tz
 
-    largest = max (abs (dx), abs (dy), abs (dz)) * 1. # We want a float
+    largest = float(max(abs(dx), abs(dy), abs(dz)))
     dx, dy, dz = dx / largest, dy / largest, dz / largest # We make a vector which maximum value is 1.0
 
-    while abs (ox - tx) > 1 or abs (oy - ty) > 1 or abs (oz - tz) > 1:
+    yield rx, ry, rz
+
+    while abs(ox - tx) > 1 or abs(oy - ty) > 1 or abs(oz - tz) > 1:
         tx += dx
         ty += dy
         tz += dz
-        if (ty < 0 and dy < 0) or (ty >= 127 and dy > 0):
-            break
-        rx, ry, rz = int (tx), int (ty), int (tz)
-        yield rx, ry, rz
+        yield int(tx), int(ty), int(tz)
+
+    yield ox, oy, oz
+
+class HurpPoint(object):
+
+    def __init__(self, t):
+        self.x, self.y, self.z = t
+
+def gen_close_point(point1, point2):
+    """
+    Retrieve the first integer set of coordinates on the line from the first
+    point to the second point.
+
+    The set of coordinates corresponding to the first point will not be
+    retrieved.
+    """
+
+    point1 = HurpPoint(point1)
+    point2 = HurpPoint(point2)
+
+    g = gen_line_simple(point1, point2)
+    next(g)
+    return next(g)
 
 def gen_line_covered(point1, point2):
     """
@@ -70,25 +61,25 @@ def gen_line_covered(point1, point2):
     """
 
     tx, ty, tz = point1.x, point1.y, point1.z # t is for temporary
-    rx, ry, rz = int (tx), int (ty), int (tz) # r is for rounded
+    rx, ry, rz = int(tx), int(ty), int(tz) # r is for rounded
     ox, oy, oz = point2.x, point2.y, point2.z # o is for objective
 
     dx = ox - tx
     dy = oy - ty
     dz = oz - tz
 
-    largest = max (abs (dx), abs (dy), abs (dz)) * 1. # We want a float
+    largest = float(max(abs(dx), abs(dy), abs(dz)))
     dx, dy, dz = dx / largest, dy / largest, dz / largest # We make a vector which maximum value is 1.0
-    adx, ady, adz = abs (dx), abs (dy), abs (dz)
+    adx, ady, adz = abs(dx), abs(dy), abs(dz)
 
     px, py, pz = rx, ry, rz
-    while abs (ox - tx) > 1 or abs (oy - ty) > 1 or abs (oz - tz) > 1:
+    while abs(ox - tx) > 1 or abs(oy - ty) > 1 or abs(oz - tz) > 1:
         tx += dx
         ty += dy
         tz += dz
         if (ty < 0 and dy < 0) or (ty >= 127 and dy > 0):
             break
-        rx, ry, rz = int (tx), int (ty), int (tz)
+        rx, ry, rz = int(tx), int(ty), int(tz)
 
         yield rx, ry, rz
 
