@@ -13,12 +13,10 @@ from twisted.internet.task import coiterate, LoopingCall
 from twisted.python import log
 
 from bravo.chunk import Chunk
-from bravo.config import configuration
 from bravo.entity import Player, Furnace
 from bravo.errors import ChunkNotLoaded, SerializerReadException
-from bravo.ibravo import ISerializer, ISerializerFactory
-from bravo.plugin import (retrieve_named_plugins, verify_plugin,
-    PluginException)
+from bravo.ibravo import ISerializer
+from bravo.plugin import retrieve_named_plugins
 from bravo.utilities.coords import split_coords
 from bravo.utilities.temporal import PendingEvent
 from bravo.mobmanager import MobManager
@@ -122,13 +120,14 @@ class World(object):
     saved in the level data.
     """
 
-    def __init__(self, name):
+    def __init__(self, config, name):
         """
         :Parameters:
             name : str
                 The configuration key to use to look up configuration data.
         """
 
+        self.config = config
         self.config_name = "world %s" % name
 
         self.chunk_cache = weakref.WeakValueDictionary()
@@ -141,20 +140,22 @@ class World(object):
         Load a world from disk.
         """
 
-        world_url = configuration.get(self.config_name, "url")
-        world_sf_name = configuration.get(self.config_name, "serializer")
+        world_url = self.config.get(self.config_name, "url")
+        world_sf_name = self.config.get(self.config_name, "serializer")
 
-        try:
-            sf = retrieve_named_plugins(ISerializerFactory, [world_sf_name])[0]
-            self.serializer = verify_plugin(ISerializer, sf(world_url))
-        except PluginException, pe:
-            log.msg(pe)
-            raise RuntimeError("Fatal error: Couldn't set up serializer!")
+        # Get the current serializer list, and attempt to connect our
+        # serializer of choice to our resource.
+        # This could fail. Each of these lines (well, only the first and
+        # third) could raise a variety of exceptions. They should *all* be
+        # fatal.
+        serializers = retrieve_named_plugins(ISerializer, [world_sf_name])
+        self.serializer = serializers[0]
+        self.serializer.connect(world_url)
 
         self.seed = random.randint(0, sys.maxint)
 
         # Check if we should offload chunk requests to ampoule.
-        if configuration.getbooleandefault("bravo", "ampoule", False):
+        if self.config.getbooleandefault("bravo", "ampoule", False):
             try:
                 import ampoule
                 if ampoule:
@@ -169,8 +170,7 @@ class World(object):
         @d.addErrback
         def sre(failure):
             failure.trap(SerializerReadException)
-            log.msg("Had issues loading level data...")
-            log.msg(failure)
+            log.msg("Had issues loading level data, continuing anyway...")
 
         # And now save our level.
         if self.saving:
@@ -313,6 +313,7 @@ class World(object):
         if not self.factory:
             return chunk
 
+        # XXX slightly icky, print statements are bad
         # Register the chunk's entities with our parent factory.
         for entity in chunk.entities:
             if hasattr(entity,'loop'):
@@ -322,12 +323,15 @@ class World(object):
                 print "I have no loop"
             self.factory.register_entity(entity)
 
-        # Scan the chunk for burning furnaces and update thir processes
+        # XXX why is this for furnaces only? :T
+        # Scan the chunk for burning furnaces
         for coords, tile in chunk.tiles.iteritems():
+            # If the furnace was saved while burning ...
             if type(tile) == Furnace and tile.burntime != 0:
                 x, y, z = coords
                 coords = chunk.x, x, chunk.z, z, y
-                reactor.callLater(2, self.factory.furnace_manager.update, coords)
+                # ... start it's burning loop
+                reactor.callLater(2, tile.changed, self.factory, coords)
 
         # Return the chunk, in case we are in a Deferred chain.
         return chunk
@@ -350,7 +354,12 @@ class World(object):
             returnValue(retval)
 
         chunk = Chunk(x, z)
-        yield maybeDeferred(self.serializer.load_chunk, chunk)
+        try:
+            yield maybeDeferred(self.serializer.load_chunk, chunk)
+        except SerializerReadException:
+            # Looks like the chunk wasn't already on disk. Guess we're gonna
+            # need to keep going.
+            pass
 
         if chunk.populated:
             self.chunk_cache[x, z] = chunk
@@ -367,7 +376,7 @@ class World(object):
                 x=x,
                 z=z,
                 seed=self.seed,
-                generators=configuration.getlist(self.config_name, "generators")
+                generators=self.config.getlist(self.config_name, "generators")
             )
 
             # Get chunk data into our chunk object.
@@ -452,6 +461,12 @@ class World(object):
         player.location.z = self.spawn[2]
 
         d = maybeDeferred(self.serializer.load_player, player)
+        @d.addErrback
+        def eb(failure):
+            failure.trap(SerializerReadException)
+            log.msg("Couldn't load player %r" % username)
+        # Add a callback to return the player, since ISerializer.load_player()
+        # doesn't return the player.
         d.addCallback(lambda none: player)
         return d
 
